@@ -1,7 +1,7 @@
 import os
 
-from base_client import BaseClient
-from utils import is_invalid_api_key
+from .base_client import BaseClient
+from .utils import is_invalid_api_key
 
 
 class OrquestaIncorrectAPIException(BaseException):
@@ -18,8 +18,6 @@ class OrquestaClient(BaseClient):
         :param api_key: Orquesta workspace API key to use. If not provided, value
                         will be read from environment variable "ORQUESTA_API_KEY".
         :type api_key: string
-        :param ttl: Time to live for the rules in the cache. Default = 3600 seconds.
-        :type ttl: int
         """
         self.api_key = api_key or os.environ.get("ORQUESTA_API_KEY")
 
